ChiantiPy.Gui.gui_qt5 package — ChiantiPy 0.15.0 documentation

# ChiantiPy.Gui.gui_qt5 package

## Submodules

## ChiantiPy.Gui.gui_qt5.gui module

PyQt5 widget selection dialogs

class `ChiantiPy.Gui.gui_qt5.gui.` `choice2Dialog`(items, label=None, parent=None, multi=True)

  Bases: `PyQt5.QtWidgets.QDialog`

  Make a single or multiple selection from a list of items and another single or multiple selection from the same list.

  Useful for picking numerators and denominators.

  expects the input of an array of items, will select one or more from both widgets.

  `accept`(self)
  `reject`(self)

class `ChiantiPy.Gui.gui_qt5.gui.` `chpicker`(dir, label)

  Bases: `PyQt5.QtWidgets.QWidget`

  dialog to select a single file name under the directory code largely taken from pythonspot.com

  `initUI`()
  `openFileNameDialog`()

class `ChiantiPy.Gui.gui_qt5.gui.` `selectorDialog`(items, label=None, parent=None, multiChoice=False)

  Bases: `PyQt5.QtWidgets.QDialog`

  Make a single or multiple selection from a list of items.

  expects the input of an array of items, will select one or more

  `accept`(self)
  `reject`(self)

## ChiantiPy.Gui.gui_qt5.ui module

class `ChiantiPy.Gui.gui_qt5.ui.` `Ui_choice2DialogForm`

  Bases: `object`

  `retranslateUi`(choice2DialogForm)
  `setupUi`(choice2DialogForm)

class `ChiantiPy.Gui.gui_qt5.ui.` `Ui_selectorDialogForm`

  Bases: `object`

  `retranslateUi`(selectorDialogForm)
  `setupUi`(selectorDialogForm)

## Module contents

PyQt5 selection dialog widgets